@@ -14,9 +14,7 @@ from concurrent.futures import Future
 from functools import partial
 from getpass import getpass
 from pprint import pprint
-from threading import current_thread
-from threading import Event
-from threading import Thread
+from threading import Event, Thread, current_thread
 
 import jupyter_client.session
 import zmq
@@ -24,41 +22,35 @@ from decorator import decorator
 from ipykernel.comm import Comm
 from IPython import get_ipython
 from IPython.core.application import BaseIPythonApplication
-from IPython.core.profiledir import ProfileDir
-from IPython.core.profiledir import ProfileDirError
+from IPython.core.profiledir import ProfileDir, ProfileDirError
 from IPython.paths import get_ipython_dir
 from IPython.utils.capture import RichOutput
 from IPython.utils.coloransi import TermColors
 from IPython.utils.path import compress_user
-from jupyter_client.localinterfaces import is_local_ip
-from jupyter_client.localinterfaces import localhost
+from jupyter_client.localinterfaces import is_local_ip, localhost
 from jupyter_client.session import Session
 from tornado import ioloop
-from traitlets import Any
-from traitlets import Bool
-from traitlets import Bytes
-from traitlets import default
-from traitlets import Dict
-from traitlets import HasTraits
-from traitlets import Instance
-from traitlets import List
-from traitlets import Set
-from traitlets import Unicode
+from traitlets import (
+    Any,
+    Bool,
+    Bytes,
+    Dict,
+    HasTraits,
+    Instance,
+    List,
+    Set,
+    Unicode,
+    default,
+)
 from traitlets.config.configurable import MultipleInstanceError
 from zmq.eventloop.zmqstream import ZMQStream
 
-from .asyncresult import AsyncHubResult
-from .asyncresult import AsyncResult
-from .futures import MessageFuture
-from .futures import multi_future
-from .view import BroadcastView
-from .view import DirectView
-from .view import LoadBalancedView
-from ipyparallel import error
-from ipyparallel import serialize
-from ipyparallel import util
-from ipyparallel.serialize import PrePickled
-from ipyparallel.serialize import Reference
+from ipyparallel import error, serialize, util
+from ipyparallel.serialize import PrePickled, Reference
+
+from .asyncresult import AsyncHubResult, AsyncResult
+from .futures import MessageFuture, multi_future
+from .view import BroadcastView, DirectView, LoadBalancedView
 
 pjoin = os.path.join
 jupyter_client.session.extract_dates = lambda obj: obj
@@ -1036,14 +1028,9 @@ class Client(HasTraits):
         """Make my IOLoop. Override with IOLoop.current to return"""
         # runs first thing in the io thread
         # always create a fresh asyncio loop for the thread
-        asyncio_loop = asyncio.new_event_loop()
-        if hasattr(asyncio, 'ProactorEventLoop') and isinstance(
-            asyncio_loop, asyncio.ProactorEventLoop
-        ):
-            asyncio_loop = asyncio.SelectorEventLoop()
-        asyncio.set_event_loop(asyncio_loop)
-        loop = ioloop.IOLoop()
-        loop.make_current()
+        if os.name == "nt":
+            asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
+        loop = ioloop.IOLoop(make_current=False)
         return loop
 
     def _stop_io_thread(self):
@@ -1077,7 +1064,7 @@ class Client(HasTraits):
         self._io_thread.daemon = True
         self._io_thread.start()
         # wait for the IOLoop to start
-        for i in range(10):
+        for i in range(20):
             if evt.wait(1):
                 return
             if not self._io_thread.is_alive():
